/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.springframework.security.web.PortMapper;

/**
 * Specify the SSL policy to follow for a concrete event.
 * If specified on an Action class this policy will apply to all events
 * unless otherwise specified.
 * When an incoming GET request is intercepted, if the security requirements are not
 * fulfilled it will be redirected (80 to 443 if SSL is required, for example).
 * If the incoming request is not a GET request and the SSL requirements are not fulfilled,
 * an exception will be thrown.
 * 
 * If there is a {@link PortMapper} instance configured in spring it 
 * will be used, otherwise the 
 * 
 * @author Ignacio Coloma
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD, ElementType.TYPE})
@Documented
@Inherited
public @interface SSLPolicy {

	/**
	 * The policy value
	 */
	SSLPolicyType value();
	
}
