package org.loom.annotation.processor;

import java.util.Set;

import org.loom.action.Action;
import org.loom.mapping.ActionMapping;
import org.loom.mapping.Event;

import com.google.common.collect.Sets;

/**
 * Anotation processor that will only get executed once per annotation class
 * @author icoloma
 *
 */
public abstract class AbstractOncePerClassAnnotationProcessor extends AbstractAnnotationProcessor {

	/** the list of visited action classes */
	private Set<Class<? extends Action>> visitedClasses = Sets.newHashSet();
	
	@Override
	public final void process(Event event) {
		Class<? extends Action> actionClass = event.getActionMapping().getActionClass();
		if (!visitedClasses.contains(actionClass)) {
			visitedClasses.add(actionClass);
			process(event.getActionMapping());
		}
	}

	protected abstract void process(ActionMapping actionMapping);

}
