/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.mapping.Event;

/**
 * Processes the annotations of a class, configuring its mapping 
 * as indicated by the annotations
 * @author icoloma
 *
 */
public interface AnnotationProcessor extends Comparable<AnnotationProcessor> {

	/**
	 * Expands an ActionMapping with the metadata annotated to an Action class.
	 * This method processes any annotations attached to the Action class or any containing package.
	 * @param event the event to be modified
	 */
	public void process(Event event);
	
	/**
	 * Annotation processors get executed in order. This method returns the expected order, where
	 * 0 is the first an Integer.MAX_VALUE is the last processor. 
	 */
	public int getOrder();
	
}
