package org.loom.annotation.processor;

import org.loom.annotation.BrowserMessages;
import org.loom.i18n.MessagesRepositoryFactory;
import org.loom.mapping.ActionMapping;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * Processes {@link BrowserMessages} annotations
 * @author icoloma
 *
 */
@Component
public class BrowserMessagesAnnotationProcessor extends AbstractOncePerClassAnnotationProcessor {

	/** the {@link MessagesRepositoryFactory} instance where browser message keys will be added */
	@Autowired
	private MessagesRepositoryFactory messagesRepositoryFactory;

	@Override
	public void process(ActionMapping mapping) {
		BrowserMessages messages = mapping.getActionClass().getAnnotation(BrowserMessages.class);
		if (messages != null) {
			for (String message : messages.value()) {
				messagesRepositoryFactory.addBrowserMessage(message);
			}
		}
	}

	public void setMessagesRepositoryFactory( MessagesRepositoryFactory messagesRepositoryFactory) {
		this.messagesRepositoryFactory = messagesRepositoryFactory;
	}

}
