/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import org.loom.annotation.validation.DateValidation;
import org.loom.annotation.validation.DateValidations;
import org.loom.mapping.Event;
import org.loom.validator.ValueParser;
import org.loom.validator.date.DateValidator;
import org.springframework.stereotype.Component;


/**
 * Processes {@link DateValidation} annotations
 * @author icoloma
 *
 */
@Component
public class DateValidationAnnotationProcessor extends AbstractPropertyAnnotationProcessor<DateValidation, DateValidations> {

	public DateValidationAnnotationProcessor() {
		super(DateValidation.class, DateValidations.class);
	}

	@Override
	protected void process(Event event, DateValidation annotation, String propertyPath) {
		DateValidator validator = new DateValidator();
		validator.setBindMessages(annotation.bindMessages());
		validator.setPropertyPath(propertyPath);
		if (annotation.message().length() > 0) {
			validator.setOverridenMessageKey(annotation.message());
		}
		if (annotation.minValue().length() > 0) {
			validator.setMinValue(ValueParser.parseDateValue(annotation.minValue()));
		}
		if (annotation.maxValue().length() > 0) {
			validator.setMaxValue(ValueParser.parseDateValue(annotation.maxValue()));
		}
		validator.setExcludeMin(annotation.excludeMin());
		validator.setExcludeMax(annotation.excludeMax());
		event.addValidator(validator);
	}

}
