/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.annotation.processor;

import java.util.Set;

import org.loom.annotation.EagerProperties;
import org.loom.annotation.EagerProperty;
import org.loom.interceptor.EagerPropertyInterceptor;
import org.loom.mapping.Event;
import org.springframework.stereotype.Component;


/**
 * Processes {@link EagerProperty} and {@link EagerProperties} annotations
 * @author icoloma
 *
 */
@Component
public class EagerPropertyAnnotationProcessor extends AbstractPropertyAnnotationProcessor<EagerProperty, EagerProperties> {

	public EagerPropertyAnnotationProcessor() {
		super(EagerProperty.class, EagerProperties.class);
	}

	@Override
	protected void process(Event event, EagerProperty annotation, String propertyPath) {
		Set<EagerPropertyInterceptor> interceptors = event.getInterceptors().findInterceptorsWithClass(EagerPropertyInterceptor.class);
		EagerPropertyInterceptor interceptor;
		if (interceptors.isEmpty()) {
			interceptor = new EagerPropertyInterceptor();
			event.addInterceptor(interceptor);
		} else {
			interceptor = interceptors.iterator().next();
		}
		interceptor.addPropertyPath(propertyPath);
	}

}
