/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.binding;

import java.lang.annotation.Annotation;

/**
 * An annotated property or method
 * @author icoloma
 *
 */
public interface AnnotationContainer {

	/**
	 * @return the list of annotations assigned to this container
	 */
	public Annotation[] getAnnotations();
	
	/**
	 * @return the instance of the provided annotation class, null if none is present.
	 */
	public abstract <T extends Annotation> T getAnnotation(Class<T> annotationClass);
	
	/**
	 * @return the name used to display error or informational messages
	 */
	public String getDisplayName();

	/**
	 * @return the name of this method or property
	 */
	public String getName();

	/**
	 * @return the class of this property/parameter
	 */
	@SuppressWarnings("unchecked")
	public Class getPropertyClass();

	public Class<?> guessCollectionGenericType();

	public Class<?> guessMapGenericKeyType();

	public Class<?> guessMapGenericValueType();

	/**
	 * @return true if this property is a List, Set or Array
	 */
	public boolean isCollection();

	/**
	 * @return true if this property is a Map
	 */
	public boolean isMap();
	
	public ItemMetadata getItemMetadata(int index);
	
	public int getItemMetadataSize();
	
}
