/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.binding.factories;

import java.lang.reflect.Array;

/**
 * ImplementationFactory for static arrays. Array access is read-only, since an 
 * array length cannot be changed at runtime without reallocating it. Thus,
 * this ImplementationFactory throws an exception if it ever gets called.
 * @author icoloma
 *
 */
public class ArrayImplementationFactory implements ImplementationFactory<Object> {

	/** the class of each node in the array */
	private Class<?> nodeClass;
	
	public ArrayImplementationFactory(Class<?> nodeClass) {
		this.nodeClass = nodeClass;
	}

	public Object newInstance() {
		// return an initial size of 1. The array may get resized elsewhere if needed
		return Array.newInstance(nodeClass, 1);
	}

}
