/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import org.apache.commons.lang.StringUtils;
import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;

/**
 * A class that must be able to perform the conversion from and to 
 * a String value.
 * @author Ignacio Coloma
 */
public abstract class AbstractStringConverter extends AbstractConverter implements Converter {

	protected AbstractStringConverter(Class<?> convertedClass) {
		super(convertedClass);
	}

	/**
	 * Return the object value for the given text
	 * @param value the value that is being parsed
	 * @return the parsed value (can be null), maybe ading new values to the errors array 
	 */
	public Object getAsObject(String name, String value, Messages messages, MessagesRepository repository) {
		return StringUtils.isEmpty(value)? null : getAsObjectImpl(name, value,  messages, repository);
	}
	
	/**
	 * This method is the getAsObject implementation, and has the guarantee that the value is not null
	 */
	protected abstract Object getAsObjectImpl(String name, String value, Messages messages, MessagesRepository repository);

	/**
	 * Return the text value for the given object
	 * @param value the java object to convert to text 
	 * @param repository the MessagesRepository object
	 * @return the parsed value (can be null) 
	 */
	public final String getAsText(Object value, MessagesRepository repository) {
		return value == null? null : getAsTextImpl(value, repository);
	}
	
	/**
	 * This method is the getAsText implementation, and has the guarantee that the value is not null
	 */
	protected String getAsTextImpl(Object value, MessagesRepository repository) {
		return value.toString();
	}

}

