/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;


/**
 * Converter for any enum class.
 * @author icoloma
 */
public class EnumConverter<T extends Enum<T>> extends AbstractSimpleConverter {

	/** the enumeration to convert from and to */
	private Class<T> enumClass;
	
	public EnumConverter(Class<T> enumClass) {
		super(enumClass);
		this.enumClass = enumClass;
	}

	/**
	 * this converter does not treat conversion errors gracefully, as it seems
	 * that a wrong enum value is a misdesigned UI. Use components that do not
	 * allow these things to happen.
	 * Instead of adding a error message, a wrong value will throw a 
	 * IllegalArgumentException
	 */
	@Override
	public Object getAsObject(String text) {
		return Enum.valueOf(enumClass, text);
	}

}
