/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.converter;

import org.loom.binding.PropertyWrapper;
import org.loom.exception.ConverterNotFoundException;
import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;

/**
 * Class used as a null substitute.
 * It is used in annotations to indicate that a property hasn't specified 
 * a concrete converter, and at runtime to mark properties that may be
 * accessed but not converted (for example, validation method containers)
 * 
 * TODO This class should be removed in the future
 * 
 * @author Ignacio Coloma
 *
 */
public class NullConverter extends AbstractConverter implements LocaleUnawareConverter {

	private PropertyWrapper propertyWrapper;
	
	public NullConverter(PropertyWrapper propertyWrapper) {
		super(propertyWrapper.getPropertyClass());
		this.propertyWrapper = propertyWrapper;
	}

	public Object getAsObject(String name, String value, Messages messages, MessagesRepository repository) {
		// this converter is only assigned when there is no suitable converter 
		// for the property class (e.g., property binders for complex objects,
		// to be able to call its @ValidationMethod)
		throw new ConverterNotFoundException(propertyWrapper);
	}

	public String getAsText(Object value, MessagesRepository repository) {
		return value == null? null : value.toString();
	}

	public Object getAsObject(String text) {
		throw new ConverterNotFoundException(propertyWrapper);
	}
	
}
