/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.exception;

import javax.persistence.PersistenceException;

/**
 * An error produced when a persitent entity could not be found.
 * It will be delivered to the browser as a 404 error 
 * @author icoloma
 *
 */
public class EntityNotFoundException extends PersistenceException implements HttpThrowable {
	
	public EntityNotFoundException(Class<?> entityClass, Object entityId) {
		this(entityClass, entityId, null, null);
	}
	
	public EntityNotFoundException(Class<?> entityClass, Object entityId, Throwable cause) {
		this(entityClass, entityId, null, cause);
	}
	
	public EntityNotFoundException(Class<?> entityClass, Object entityId, String message) {
		this(entityClass, entityId, message, null);
	}
	
	public EntityNotFoundException(Class<?> entityClass, Object entityId, String message, Throwable cause) {
		super(message != null? message : "Instance of " + entityClass.getName() + " with primary key " + entityId + " cannot be found", cause);
	}
	
	/**
	 * Entity not found is typically presented as a 404 error
	 */
	public int getHttpError() {
		return 404;
	}
}
