package org.loom.exception;


/**
 * This exception can be used at any moment to return the specified HTTP error code to the browser.
 * The browser will be pesented with a generic HTTP error page, but the system log 
 * will log the real cause (the provided error message)
 * @author icoloma
 *
 */
public class HttpException extends RuntimeException implements HttpThrowable {

	/** the http error code to be returned */
	private int httpError; 
	
	/**
	 * @param httpError the http error code to be returned to the browser
	 * @param message the error message that will be logged in the system log (not presented to the browser)
	 */
	public HttpException(int httpError, String message) {
		this(httpError, message, null);
	}
	
	/**
	 * @param httpError the http error code to be returned to the browser
	 * @param message the error message that will be logged in the system log (not presented to the browser)
	 */
	public HttpException(int httpError, String message, Throwable cause) {
		super(message, cause);
		this.httpError = httpError;
	}
	
	/**
	 * @param httpError the http error code to be returned to the browser
	 * @param cause the cause of this exception
	 */
	public HttpException(int httpError, Throwable cause) {
		super(cause);
		this.httpError = httpError;
	}
	
	public int getHttpError() {
		return httpError;
	}

}
