/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.exception;

import org.loom.i18n.Message;
import org.loom.i18n.Messages;
import org.loom.i18n.MessagesRepository;

/**
 * This exception is raised when there are validation errors but there is no user form to redirect to.
 * This usually means that there is a malformed redirect or GET link somewhere.
 * 
 * @author icoloma
 *
 */
public class UnhandledValidationErrorsException extends RuntimeException implements LocaleAwareThrowable, HttpThrowable {

	private Messages messages;
	
	public UnhandledValidationErrorsException(Messages messages, MessagesRepository repository) {
		super(repository.translateMessage(messages.getAllMessages().get(0)));
		this.messages = messages;
	}

	public Messages getMessages() {
		return messages;
	}

	public Message getLocaleAwareMessage() {
		return messages.getAllMessages().get(0);
	}

	/**
	 * 400 (malformed request) seems the most appropiate  http error to return 
	 */
	public int getHttpError() {
		return 400;
	}

}
