/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.i18n;

import java.util.Locale;
import java.util.Set;

/**
 * Instantiates and caches the MessageRepository instances
 * @author icoloma
 */
public interface MessagesRepositoryFactory {

	/**
	 * Return the MessagesRepository instance corresponding to this Locale.
	 */
	public MessagesRepository getRepository(Locale locale);

	/**
	 * Add a JSON message key.
	 * @param messageKey the message key to be added
	 */
	public void addBrowserMessage(String messageKey);

	/**
	 * Replace the current set of JSON keys.
	 * This is the list of messages keys that will be sent to the browser 
	 * as a JSON object.
	 * @param browserMessages the new set of JSON keys
	 */
	public void setBrowserMessages(Set<String> browserMessages);

	/**
	 * @return the locale applied by default. Defaults to Locale.getDefaultLocale() 
	 */
	public Locale getDefaultLocale();
	
	/**
	 * Add a MessagesRepositoryEventListener to listen to creation events  
	 */
	public void addMessagesRepositoryEventListener(MessagesRepositoryEventListener listener);
	
	/**
	 * Add a location at the beginning of the locations list.
	 * This method  is intended for adding locations  provided by loom extensions at the begining of
	 * the locationslist, so the user can still override any resources with his own messages files 
	 * if he decides to.
	 * TODO: This method should be removed from the interface or redesigned
	 * @param location the location to be added.
	 */
	public void addExtensionLocation(String location);
	
}
