/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.interceptor;

import java.util.Set;

import org.loom.mapping.ParsedAction;
import org.loom.resolution.Resolution;
import org.loom.servlet.params.ServletRequestParameters;

import com.google.common.collect.Sets;

/**
 * Assigns an eager property before the population phase
 * @author icoloma
 */
public class EagerPropertyInterceptor implements CreateInterceptor {

	/** list of eager properties for this event */
	private Set<String> properties = Sets.newHashSet();
	
	public Resolution afterCreate(ParsedAction action) {
		ServletRequestParameters original = action.getRequest().getRequestParameters();
		ServletRequestParameters copy = action.getRequest().getRequestParameters();
		for (String propertyName : properties) {
			copy.addStringParameter(propertyName, original.getStringParameter(propertyName));
		}
		action.populate(copy);
		return null;
	}

	public void addPropertyPath(String propertyPath) {
		properties.add(propertyPath);
	}

	public Set<String> getProperties() {
		return properties;
	}


}
