/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.mapping;

import java.util.SortedSet;

import org.loom.action.Action;
import org.loom.annotation.processor.AnnotationProcessor;


/**
 * Class that creates ActionMapping and ActionMappingRepository instances
 * @author icoloma
 *
 */
public interface ActionMappingFactory {

	/**
	 * Create an {@link ActionMapping}
	 * @param beanName the name of the spring bean used to create each Action instance
	 * @param actionClass the action class
	 * @return the created ActionMapping instance
	 */
	public ActionMapping create(String beanName, Class<? extends Action> actionClass);

	public SortedSet<AnnotationProcessor> getAnnotationProcessors();

	public void addAnnotationProcessor(AnnotationProcessor processor);

}
