package org.loom.mapping;

import java.util.Comparator;
import java.util.List;

/**
 * Compares Events to retrieve in its mapping processing order.
 * This Comparator ensures that we test first the Events with best tokens fit,
 * which means:
 * 
 * "/foo/{param1}" gets processed before "/{param1}/{param2}"
 * "/{param1}/edit" gets processed before "/{param1}" 
 * 
 * @author icoloma
 *
 */
public class EventComparator implements Comparator<Event> {

	public int compare(Event e1, Event e2) {
		List<UriToken> tokens1 = e1.getUriParser().getTokens();
		List<UriToken> tokens2 = e2.getUriParser().getTokens();
		int size1 = tokens1.size();
		int size2 = tokens2.size();
		int max = Math.min(size1, size2);
		
		// compare the longest token common path
		int value = 0;
		for (int i = 0; i < max && value == 0; i++) {
			UriToken token1 = tokens1.get(i);
			UriToken token2 = tokens2.get(i);
			value = token2.getHandle().compareTo(token1.getHandle());
		}
		
		// if the tokens are the same, return the comparison of event names 
		return value != 0? value :
			   size1 != size2? size2 - size1 :
			   e1.getName().compareTo(e2.getName());
	}
	
}
