package org.loom.paged;

/**
 * The sort order of a PagedList request.
 * @author icoloma
 *
 */
public enum SortOrder {

	ASCENDING("asc"),
	
	DESCENDING("desc");
	
	/** the value of the sortOrder GET parameter */
	private String value;
	
	public String getValue() {
		return value;
	}

	private SortOrder(String value) {
		this.value = value;
	}
	
	/**
	 * @return the opposite to this order
	 */
	public SortOrder getOpposite() {
		return ASCENDING == this? DESCENDING : ASCENDING;
	}
	
	/**
	 * @return the SortOrder corresponding to the provided value (ASCENDING for "asc", DESCENDING for "desc")
	 * if value is null, return ASCENDING
	 */
	public static SortOrder fromValue(String value) {
		if (value == null || "asc".equals(value))
			return ASCENDING;
		else if ("desc".equals(value)) 
			return DESCENDING;
		else
			throw new IllegalArgumentException("Unknown SortOrder value: " + value);
	}
	
}
