/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import org.apache.commons.lang.StringUtils;
import org.codehaus.jackson.map.ObjectMapper;
import org.loom.action.Action;
import org.loom.persistence.file.PersistentFile;

/**
 * Default ResolutionFactory implementation 
 * @author icoloma
 */
public class DefaultResolutionFactoryImpl implements ResolutionFactory {

	/** default forward resources root */
	private String forwardResourcesRoot = "/WEB-INF/jsp";
	
	/** used to serialize JSON */
	private ObjectMapper mapper;
	
	public ForwardResolution forward(String pageName) {
		ForwardResolutionImpl resolution = new ForwardResolutionImpl();
		resolution.setForwardResourcesRoot(forwardResourcesRoot);
		resolution.setDestination(pageName);
		return resolution;
	}
	
	public ForwardResolution forwardWithLocale(String pageName) {
		LocaleForwardResolutionImpl resolution = new LocaleForwardResolutionImpl();
		resolution.setForwardResourcesRoot(forwardResourcesRoot);
		resolution.setDestination(pageName);
		return resolution;
	}
	
	public PersistentFileResolution send(PersistentFile file) {
		return new PersistentFileResolution(file);
	}
	
	public RedirectResolution redirect(String url) {
		return new RedirectResolutionImpl(url);
	}
	
	public RedirectResolution redirect(String action, String event) {
		return new RedirectResolutionImpl(action, event);
	}
	
	public RedirectResolution redirect(Class<? extends Action> actionClass, String event) {
		return new RedirectResolutionImpl(actionClass, event);
	}

	public String getForwardResourcesRoot() {
		return forwardResourcesRoot;
	}

	public void setForwardResourcesRoot(String forwardResourcesRoot) {
		if (!StringUtils.isEmpty(forwardResourcesRoot) && forwardResourcesRoot.charAt(forwardResourcesRoot.length() - 1) == '/') {
			forwardResourcesRoot = forwardResourcesRoot.substring(0, forwardResourcesRoot.length() - 1);
		}
		this.forwardResourcesRoot = forwardResourcesRoot;
	}
	
	public JacksonResolution json(Object contents) {
		return new JacksonResolution(mapper, contents);
	}

	public ObjectMapper getMapper() {
		return mapper;
	}

	public void setMapper(ObjectMapper mapper) {
		this.mapper = mapper;
	}


}
