/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import java.io.IOException;

import javax.servlet.ServletException;

import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.tags.StringWriterWrapper;

/**
 * A Resolution class to compose HTML by hand.
 * @author Ignacio Coloma
 */
public class HtmlResolution extends AbstractHttpResolution {

	/** the contents of the response */
	private StringWriterWrapper wrapper = new StringWriterWrapper();
	
	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		response.setContentType("text/html");
		writeHeaders(request, response);
		response.getWriter().write(wrapper.getContents());
	}
	
	/**
	 * Print text
	 * @param seq the text to print
	 * @return this same instance
	 */
	public HtmlResolution print(CharSequence seq) throws IOException {
		wrapper.print(seq);
		return this;
	}
	
	/**
	 * Print an attribute, if its value is not null. Else, does nothing
	 * @param name the name of the attribute
	 * @param value the value of the attribute that will be printed (invoking toString())
	 * @return this same instance
	 */
	public HtmlResolution printAttribute(String name, Object value) throws IOException {
		wrapper.printAttribute(name, value);
		return this;
	}
	
	/**
	 * Print a input type="hidden" field
	 * @param name the name of the field
	 * @param value the value that will be printed (invoking toString())
	 * @return this same instance
	 */
	public HtmlResolution printHiddenField(String name, String value) throws IOException {
		wrapper.printHiddenField(name, value);
		return this;
	}
	
	/**
	 * Write a javascript start tag
	 */
	public HtmlResolution startJavascript() throws IOException {
		wrapper.startJavascript();
		return this;
	}
	
	/**
	 * Write a javascript end tag
	 */
	public HtmlResolution endJavascript() throws IOException {
		wrapper.endJavascript();
		return this;
	}
	
	/**
	 * @return the contents of this resolution object, as String
	 */
	public String getContents() {
		return wrapper.getContents();
	}

	public StringWriterWrapper getWriterWrapper() {
		return wrapper;
	}

}
