/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import java.io.IOException;

import javax.servlet.ServletException;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.codehaus.jackson.map.ObjectMapper;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;

/**
 * A resolution that uses Jackson to serialize a JSON response.
 * @author Ignacio Coloma
 */
public class JacksonResolution extends AbstractHttpResolution {

	/** the object that does the real marshalling */
	private ObjectMapper mapper;
	
	/** the contents pof this response object */
	private Object contents;
	
	public JacksonResolution(ObjectMapper mapper, Object contents) {
		this.mapper = mapper;
		this.contents = contents;
	}
	
	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		if (getContentType() == null) {
			setContentType("application/json");
		}
		writeHeaders(request, response);
		mapper.writeValue(response.getWriter(), contents);
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this).append("mapper",  mapper).toString();
	}

	public ObjectMapper getMapper() {
		return mapper;
	}

	public Object getContents() {
		return contents;
	}
	
}
