/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.resolution;

import java.io.IOException;

import javax.servlet.ServletException;

import org.loom.json.JsonMarshaller;
import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;

/**
 * Returns a json object as the response body or HTTP header.
 * @deprecated use {@link JacksonResolution} instead (available via AbstractAction.json(contents))
 * @author Ignacio Coloma
 */
public class JsonResolution extends AbstractHttpResolution {

	/** the object that does the real marshalling */
	private JsonMarshaller marshaller;
	
	/** the transport to be used, default to AS_HTML_SCRIPT */
	private Transport transport = Transport.AS_HTML_SCRIPT;
	
	// TODO this is overdesigned and should be simplified.
	public enum Transport {
		
		/** send as X-JSON http header */
		AS_HTTP_HEADER("text/html"), 
		
		/** this is the approved content-type for json contents */
		AS_HTML_SCRIPT("application/json");
		
		/** default content type used for this transport */
		public final String contentType;
		
		Transport(String contentType) { this.contentType = contentType; }
		
	}
	
	public JsonResolution() {
		this(new JsonMarshaller());
	}
	
	public JsonResolution(JsonMarshaller marshaller) {
		this.marshaller = marshaller;
	}
	
	@Override
	public void resolve(LoomServletRequest request, LoomServletResponse response) throws IOException, ServletException {
		if (getContentType() == null) {
			setContentType(transport.contentType);
		}
		if (Transport.AS_HTML_SCRIPT.equals(transport)) {
			writeHeaders(request, response);
			response.getWriter().write(marshaller.toString());
		} else {
			setJsonHeader(marshaller);
			writeHeaders(request, response);
			// some browsers do not like empty responses.
			response.getWriter().write(" ");
		}
	}

	@Override
	public String toString() {
		return "JsonResolution " + marshaller;
	}

	public Transport getTransport() {
		return transport;
	}

	public void setTransport(Transport transport) {
		this.transport = transport;
	}

	/**
	 * Add a JSON property to this object
	 * @param name the name of the property
	 * @param value the value
	 */
	public JsonResolution addJsonProperty(String name, Object value) {
		marshaller.add(name, value);
		return this;
	}

	public JsonMarshaller getMarshaller() {
		return marshaller;
	}
	
	
}
