package org.loom.resources;

import static org.loom.config.ClassNames.YUICOMPRESSOR;

import org.loom.log.Log;
import org.loom.resources.compressor.NullCompressor;
import org.loom.resources.compressor.WebResourceCompressor;
import org.loom.resources.compressor.YuiCssCompressorAdapter;
import org.loom.resources.compressor.YuiJavascriptCompressorAdapter;
import org.loom.util.ClassUtils;

public abstract class AbstractWebResourceDataFactory implements WebResourceDataFactory {

	/** set to true to disable all obfuscation */
	private boolean debug;
	
	/** the compressor used for javascript files */
	private WebResourceCompressor javascriptCompressor = NULL_COMPRESSOR;
	
	/** the compressor used for CSS files */
	private WebResourceCompressor cssCompressor = NULL_COMPRESSOR;

	private static NullCompressor NULL_COMPRESSOR = new NullCompressor();
	
	/** the {@link WebResourceBundleRepository} instance to resolve bundles */
	protected WebResourceBundleRepository webResourceBundleRepository;

	private static Log log = Log.getLog();
	
	public AbstractWebResourceDataFactory() {
		if (ClassUtils.isPresent(YUICOMPRESSOR)) {
			log.info("Detected YUICompressor");
			setJavascriptCompressor(new YuiJavascriptCompressorAdapter());
			setCssCompressor(new YuiCssCompressorAdapter()); 
		} else {
			log.info("No JS/CSS compressor found in the classpath");
		}

	}
	
	public WebResourceData create(String bundleName, Integer index, String filename) {
		return create(webResourceBundleRepository.createIndexedWebResource(bundleName, index, filename));
	}
	
	public WebResourceData create(String bundleName) {
		return create(webResourceBundleRepository.getResourceBundle(bundleName));
	}
	
	protected abstract WebResourceData create(WebResource resource);

	/**
	 * @return the WebResourceCompressor instance to use for resources of the provided type. 
	 * If none is registered for this type, return null  
	 */
	protected WebResourceCompressor getCompressor(WebResource resource) {
		boolean obfuscate = !debug && !(resource.getObfuscate() != null && !resource.getObfuscate());
		if (WebResourceType.JS == resource.getType() && obfuscate) {
			return javascriptCompressor;
		} else if (WebResourceType.CSS == resource.getType() && obfuscate) {
			return cssCompressor;
		}
		return NULL_COMPRESSOR;
	}
	
	public WebResourceCompressor getJavascriptCompressor() {
		return javascriptCompressor;
	}

	public void setJavascriptCompressor(WebResourceCompressor jsCompressor) {
		this.javascriptCompressor = jsCompressor;
	}

	public WebResourceCompressor getCssCompressor() {
		return cssCompressor;
	}

	public void setCssCompressor(WebResourceCompressor cssCompressor) {
		this.cssCompressor = cssCompressor;
	}
	
	public void setWebResourceBundleRepository( WebResourceBundleRepository resourceBundleRepository) {
		this.webResourceBundleRepository = resourceBundleRepository;
	}

	public void setDebug(boolean debug) {
		this.debug = debug;
	}
	
}
