package org.loom.resources;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.security.DigestInputStream;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.zip.GZIPOutputStream;

import org.apache.commons.io.IOUtils;
import org.loom.exception.SyntaxError;
import org.loom.resources.compressor.WebResourceCompressor;
import org.loom.util.FileUtils;
import org.loom.util.StringUtils;

public class InMemoryWebResourceDataFactory extends AbstractWebResourceDataFactory {
	
	@Override
	public WebResourceData create(WebResource resource) {
		try {
			
			// concatenate and minify 
			InputStream is = null;
			ByteArrayOutputStream os = new ByteArrayOutputStream();
			try {
				is = webResourceBundleRepository.getInputStream(resource);
				WebResourceCompressor compressor = getCompressor(resource);
				compressor.compress(is, os);
			} finally {
				IOUtils.closeQuietly(is);
				IOUtils.closeQuietly(os);
			}
			byte[] contents = os.toByteArray();
			
			// gzip and calculate MD5
			os = new ByteArrayOutputStream();
			GZIPOutputStream output = null;
			DigestInputStream input = null;
			MessageDigest digest = MessageDigest.getInstance("MD5");
			try {
				input = new DigestInputStream(new ByteArrayInputStream(contents), digest);
				output = new GZIPOutputStream(os);
				FileUtils.copy(input, output);
			} finally {
				IOUtils.closeQuietly(input);
				IOUtils.closeQuietly(output);
			}

			// create the result instance
			InMemoryWebResourceData data = new InMemoryWebResourceData();
			data.setWebResource(resource);
			data.setContents(contents);
			data.setGzippedContents(os.toByteArray());
			data.setMd5(StringUtils.toString(digest));
			data.setType(resource.getType());
			data.setCharset(resource.getCharset());
			return data;
			
		} catch (SyntaxError e) {
			throw new RuntimeException("Error processing resource: " + resource.getName(), e);
		} catch (NoSuchAlgorithmException e) {
			throw new RuntimeException(e);
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
	}
	
}
