package org.loom.resources;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.List;

import org.springframework.core.io.Resource;


/**
 * An indexed web resource is a file relative to a bundle location. It can be:
 * 
 * <ul><li>An indexed javascript or CSS file: bundle/{index}/core.js</li>
 * <li>A image referred from a CSS file: bundle/{index}/img/logo.gif</li>
 * </ul> 
 * 
 * @author icoloma
 *
 */
public class IndexedWebResource implements WebResource {

	/** the file */
	private Resource resource;
	
	private WebResourceType type;
	
	/** the list of resources in this instance (will be 1) */
	private List<Resource> resources;
	
	/** the charset to be used by this resource */
	private String charset;
	
	/** the bundle index of this resource */
	private int index;
	
	public IndexedWebResource(int index, Resource resource) {
		this.resource = resource;
		this.type = WebResourceType.identify(resource);
		this.resources = Arrays.asList(resource);
		this.index = index;
	}
	
	public InputStream getInputStream() throws IOException {
		return resource.getInputStream();
	}
	
	public String getName() {
		return resource.toString();
	}

	public WebResourceType getType() {
		return type;
	}

	public Resource getResource() {
		return resource;
	}

	public void setResource(Resource resource) {
		this.resource = resource;
	}

	public void setType(WebResourceType type) {
		this.type = type;
	}

	public List<Resource> getResources() {
		return resources;
	}

	public String getCharset() {
		return charset;
	}

	public void setCharset(String charset) {
		this.charset = charset;
	}

	public int getIndex() {
		return index;
	}

	public Boolean getObfuscate() {
		return null;
	}

	
	
	
}
