package org.loom.resources;

import java.io.IOException;
import java.io.InputStream;
import java.util.Iterator;

/**
 * This is a port of SequenceInputStream to work with ArrayList. Refer
 * to SequenceInputStream javadoc for instructions of use.
 * @author icoloma
 *
 */
public class MultipleInputStream extends InputStream {

    Iterator<? extends InputStream> e;
    InputStream in;

    public MultipleInputStream(Iterator<? extends InputStream> e) throws IOException {
		this.e = e;
	    nextStream();
    }

    final void nextStream() throws IOException {
		if (in != null) {
		    in.close();
		}

        in = e.hasNext()? e.next() : null;

    }

    public int available() throws IOException {
		return in == null? 0 : in.available();
    }

    public int read() throws IOException {
		if (in == null) {
		    return -1;
		}
		int c = in.read();
		while (c == -1 && e.hasNext()) {
		    nextStream();
		    c = read();
		}
		return c;
    }

    public int read(byte b[], int off, int len) throws IOException {
		if (in == null) {
		    return -1;
		} else if (len == 0) {
		    return 0;
		}
	
		int n = in.read(b, off, len);
		if (n <= 0) {
		    nextStream();
		    return read(b, off, len);
		}
		return n;
    }

    public void close() throws IOException {
    	while (in != null) {
    		nextStream();
    	}
    }
    
}
