package org.loom.resources;

import java.util.ArrayList;
import java.util.List;

import org.springframework.core.io.Resource;

/**
 * A list of resources (javascript or css files) to be merged before delivering to the browser.
 * @author icoloma
 *
 */
public class WebResourceBundle implements WebResource {

	/** the list of resource locations */
	private List<Resource> resources = new ArrayList<Resource>();
	
	/** the name of this instance */
	private String name;
	
	/** the type of the bundle (javascript, css or unknown) */
	private WebResourceType type = WebResourceType.UNKNOWN;
	
	/** the compressor to apply */
	private Boolean obfuscate;

	/** the character encoding to be used for this bundle */
	private String charset;
	
	public void add(Resource resource) {
		if (!resources.contains(resource)) {
			resources.add(resource);
			if (WebResourceType.UNKNOWN == type) {
				type = WebResourceType.identify(resource);
			}
		}
	}

	/**
	 * @return true if this bundle contains the specified resource
	 */
	public boolean contains(Resource resource) {
		// this is safe, since all Resource implementations include a customized hashCode() and equals()
		return resources.contains(resource);
	}
	
	/**
	 * @return the index of the specified resource, -1 if not found
	 */
	public int indexOf(Resource resource) {
		if (!resources.contains(resource)) {
			return -1;
		}
		int i = 0;
		for (Resource r : resources) {
			if (resource.equals(r)) {
				return i;
			}
			i++;
		}
		return -1;
	}
	
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Resource getResource(int index) {
		return resources.get(index);
	}
	
	public List<Resource> getResources() {
		return resources;
	}

	public WebResourceType getType() {
		return type;
	}

	public String getCharset() {
		return charset;
	}

	public void setCharset(String charset) {
		this.charset = charset;
	}

	public void setResources(List<Resource> resources) {
		for (Resource resource : resources) {
			add(resource);
		}
	}

	public Boolean getObfuscate() {
		return obfuscate;
	}

	public void setObfuscate(Boolean obfuscate) {
		this.obfuscate = obfuscate;
	}

}
