/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.names;

/**
 * The list of HTTP header names that can be applied both to request and response,
 * as specified at http://www.w3.org/Protocols/rfc2616/rfc2616-sec4.html#sec4.5
 * 
 * @author Ignacio Coloma
 */
public interface CommonHeaderNames {

	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9">Cache-Control</a> */
	public static final String CACHE_CONTROL = "Cache-Control";

	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.13">Content-Length</a> */
	public static final String CONTENT_LENGTH = "Content-Length";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.18">Date</a> */
	public static final String DATE = "Date";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.32">Pragma</a> */
	public static final String PRAGMA = "Pragma";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec45.html#sec14.32">Via</a> */
	public static final String VIA = "Via";
	
	/** <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec46.html#sec14.32">Warning</a> */
	public static final String WARNING = "Warning";

	
}
