/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.names;

import org.loom.i18n.MessagesRepository;


/**
 * Servlet request attributes used by Loom
 * @author Ignacio Coloma
 */
public interface RequestAttributeNames {

	/** the current action */
	public static final String ACTION = "action";
	
	/** the current ParsedAction instance */
	public static final String PARSED_ACTION = "parsedAction";
	
	/** the current {@link MessagesRepository} instance */
	public static final String MESSAGES_REPOSITORY = "messages"; 
	
	/** the menuItem ID that is currently selected.  */
	public static final String SELECTED_MENU_ITEM_PREFIX = "selected-menu-";
	
	/** prefix of the current value for autogenerated field index */
	public static String FIELD_INDEX_PREFIX = "index-";
	
	/** flash container with attributes of the PREVIOUS request */
	public static String FLASH_PREV = "flash-prev";
	
	/** flash container with attributes for the NEXT request */
	public static String FLASH_NEXT = "flash-next";
	
	/** When using \@Cache, the CacheControl instance associated to the current request */
	public static final String CACHE_CONTROL = "cache-control";

	/* ----+----+----+---- Third party request attributes ----+----+----+---- */
	
	/** exception attribute for error pages */
	public static final String JAVA_EXCEPTION = "javax.servlet.error.exception";
	
	/** http error code attribute for error pages */
	public static final String HTTP_ERROR = "javax.servlet.error.status_code";
	
	/** the security exception handled by spring security when returning a 403 response */
	public static final String SPRING_SECURITY_403_EXCEPTION = "SPRING_SECURITY_403_EXCEPTION";
	
	/**
	 * Original request data as received by the server before the request gets forwarded elsewhere.
	 *
	 * see http://jetty.mortbay.org/jetty5/doc/servlet24.html  
	 */
	public static final String FORWARD_URI = "javax.servlet.forward.request_uri";
	public static final String FORWARD_CONTEXT_PATH = "javax.servlet.forward.context_path"; 
	public static final String FORWARD_SERVLET_PATH = "javax.servlet.forward.servlet_path"; 
	public static final String FORWARD_PATH_INFO = "javax.servlet.forward.path_info";
	public static final String FORWARD_QUERY_STRING = "javax.servlet.forward.query_string"; 
	
}
