/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.servlet.params;

import java.io.IOException;
import java.io.InputStream;

/**
 * Uploaded field
 * @author Ignacio Coloma
 */
public interface FileParameter {

	/**
	 * Get the uploaded filename. The file path, if provided by the browser, will be removed 
	 */
	public String getFilename();

	/**
	 * Get the file content-type. If the browser does not provide one, it will be guessed using MimeUtils.
	 */
	public String getContentType();

	/**
	 * Get the file size, -1 if unknown
	 */
	public long getFileSize();

	/**
	 * Get the file contents as an input stream. 
	 */
	public InputStream getStream() throws IOException;
	
	/**
	 * Get the file contents as a byte array
	 */
	public byte[] getBytes();
	
}
