/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags;

import java.io.IOException;
import java.io.Writer;

import org.apache.commons.lang.StringUtils;

/**
 * Abstract writer implementation
 * @author icoloma
 */
public abstract class AbstractWriterWrapper<T extends Writer> implements WriterWrapper<T> {

	protected T writer;
	
	public AbstractWriterWrapper(T writer) {
		this.writer = writer;
	}

	public WriterWrapper<T> printAttribute(String name, Object value) throws IOException {
		if (value != null) {
			print(" ");
			print(name);
			print("=\"");
			print(value.toString());
			print("\"");
		}
		return this;
	}

	public T getWriter() {
		return writer;
	}
	
	public WriterWrapper<T> print(Object o) throws IOException {
		return print(o == null? "null" : o.toString());
	}

	public WriterWrapper<T> printHiddenField(String name, Object value) throws IOException {
		if (value != null) {
			print("<input type=\"hidden\"");
			printAttribute("name", name);
			printAttribute("value", value);
			print("/>\n");
		}
		return this;
	}
	
	public WriterWrapper<T> startJavascript() throws IOException {
		print("<script type=\"text/javascript\">\n");
		return this;
	}

	public WriterWrapper<T> endJavascript() throws IOException {
		print("</script>\n");
		return this;
	}
	
	public void flush() throws IOException {
		writer.flush();
	}

	public WriterWrapper<T> startEnd(String tag, Object... attributes) throws IOException {
		return internalWriteTag(tag, "/>", attributes);
	}
	
	public WriterWrapper<T> start(String tag, Object... attributes) throws IOException {
		return internalWriteTag(tag, ">", attributes);
	}
	
	private WriterWrapper<T> internalWriteTag(String tag, String end, Object... attributes) throws IOException {
		print("<").print(tag);
		if (attributes.length % 2 > 0) {
			throw new IllegalArgumentException("The number of attriobute names and values should be even: " + StringUtils.join(attributes, ", "));
		}
		int i = 0;
		while (i < attributes.length) {
			printAttribute((String)attributes[i], attributes[i + 1]);
			i += 2;
		}
		return print(end);
	}
	
	public WriterWrapper<T> end(String tag) throws IOException {
		return print("</").print(tag).print(">");
	}
	
}
