/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.config.ConfigProperties;
import org.loom.converter.Converter;
import org.loom.i18n.MessagesRepository;
import org.loom.util.HtmlSanitizer;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * <a href="http://www.w3.org/TR/html4/interact/forms.html#edef-INPUT">HTML radio button</a>.
 * This component will generate a list of labelled input fields for each possible value.
 * @author icoloma
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS,
		example=
			"&lt;l:inputRadio name=\"customer.creditType\"/>\n" +
			"&lt;l:inputRadio name=\"customer.type\">\n" +
			"	&lt;l:option label=\"--\" value=\"\" translateLabel=\"false\"/>\n" + 
			"	&lt;l:option value=\"NORMAL\" />\n" + 
			"	&lt;l:option value=\"BULK\" />\n" + 
			"&lt;/l:inputRadio>" 
			
	)
public class InputRadioTag extends AbstractOptionsTag {

	private static String DEFAULT_CSS = ConfigProperties.getInstance().getDefaultCss(InputRadioTag.class, "radio");
	
	public InputRadioTag() {
		setCssClass(DEFAULT_CSS);
	}

	/**
	 * Prints this instance attributes
	 */
	@Override
	public void doTagImpl() throws JspException, IOException {
		// evaluate any nested option
		calculateOptions();
		
		Object currentValue = getValueAsObject();
		int count = 0;
		setTranslateLabel(false);
		Converter converter = getConverter();
		MessagesRepository messagesRepository = getMessagesRepository();
		for (Option option : getNestedOptions()) {
			out.print("<label><input type=\"radio\"");
			setId(getName() + count++);
			printParentAttributes();
			if (option.getValue() != null) {
				String valueAsText = HtmlSanitizer.sanitize(converter.getAsText(option.getValue(), messagesRepository));
				out.printAttribute("value", valueAsText);
			}
			if (option.isSelected(currentValue)) {
				out.printAttribute("checked", "true");
			}
			out.print("/><span>");
			out.print(option.getLabel(repository));
			out.print("</span></label>\n");
		}

	}
	
}
