/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.core;

import org.loom.mapping.ParsedAction;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;

/**
 * outProperty has the same syntax of out, but prints the value of any 
 * action attribute using the associated Converter for the current locale.
 * 
 * @author Ignacio Coloma
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS,
		example=
			"&lt;l:outProperty name=\"mortgage.date\"/>"
	)
public class OutPropertyTag extends AbstractOutTag {

	/** the property name */
	@Attribute(required=true)
	private String name;
	
	public OutPropertyTag() {
		// escape html characters
		setEscapeHtml(true);
	}

	@Override
	protected String getDisplayValue() {
		ParsedAction parsedAction = request.getParsedAction();
		if (isIf() && parsedAction != null) {
			return parsedAction.getPropertyAsString(name);
		}
		return null;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

}
