package org.loom.tags.core;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.tags.AbstractTag;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;
import org.loom.url.ParameterContainer;
import org.loom.url.UrlBuilder;

/**
 * Redirect the current request
 * This tag is useful for index.jsp pages that will be redirected to some action class.
 * In this case, they should be used alone in an empty jsp page.
 * @author icoloma
 *
 */
@Tag(
		dynamicAttributes=true, 
		bodyContent=BodyContent.SCRIPTLESS
	)
public class RedirectTag extends AbstractTag implements ParameterContainer {

	private UrlBuilder url = new UrlBuilder();
	
	@Override
	public void doTagImpl() throws JspException, IOException {
		// process any nested parameters
		doBufferedBody();
		
		getResponse().sendRedirect(url.getURL());
	}

	public ParameterContainer addParameter(String name, Object value) {
		return url.addParameter(name, value);
	}
	
	/**
	 * The action this link points to. Either this or href must be specified
	 */
	@Attribute
	public void setAction(String action) {
		this.url.setAction(action);
	}
	
	/**
	 * The event this link points to. If action is specified but event is not, the
	 * default event will be assumed. If the action does not define a default event,
	 * an exception will be thrown.
	 * Either action/event or href must be set.
	 */
	@Attribute
	public void setEvent(String event) {
		this.url.setEvent(event);
	}
	
	/**
	 * The hash of the url (the part after '#')
	 */
	@Attribute
	public void setHash(String hash) {
		this.url.setHash(hash);
	}
	
	/**
	 * The target url. Either this or the action / event pair must be set.
	 */
	@Attribute
	public void setHref(String href) {
		this.url.setRawUrl(href);
	}

}
