/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.menu;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpSessionActivationListener;
import javax.servlet.http.HttpSessionEvent;

import org.loom.servlet.LoomServletRequest;

/**
 * Parent class of MenuData classes
 * @author icoloma
 */
public abstract class AbstractMenuData implements MenuItemDataCollection, HttpSessionActivationListener {

	private List<MenuItemData> items = new ArrayList<MenuItemData>();
	
	/** this id will be used as HTML id and to locate the MenuData in the selected cache */
	private String id;
	
	/** CSS class name */
	private String cssClass;
	
	private static final long serialVersionUID = 1L;

	/**
	 * Remove this menu from the user session if it's going to passivate. This should get invoked 
	 * (by the application server) for session-scoped menus. 
	 * The menu will be re-created again on the next user request, as it willnot be found on the user session.
	 */
    public void sessionWillPassivate(HttpSessionEvent se) {
    	se.getSession().removeAttribute(id);
    }

    public void sessionDidActivate(HttpSessionEvent se) {
    	// do nothing
    }

	public void addChild(MenuItemData item) {
		items.add(item);
		item.setParent(this); 
	}

	/**
	 * @return the currently selected item, null if none
	 */
	public abstract MenuItemData getSelectedItem(LoomServletRequest request);

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public List<MenuItemData> getChildren() {
		return items;
	}
	
	public String getCssClass() {
		return cssClass;
	}

	public void setCssClass(String cssClass) {
		this.cssClass = cssClass;
	}

	protected List<MenuItemData> getItems() {
		return items;
	}

}
