/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.menu;

import java.util.Locale;

import org.loom.servlet.LoomServletRequest;
import org.loom.servlet.LoomServletResponse;
import org.loom.tags.core.UrlTag;
import org.loom.url.UrlBuilder;

/**
 * Each Locale of the LocaleMenu
 * @author icoloma
 */
public class LocaleMenuItemData extends MenuItemData {

	/** the locale to select */
	private Locale locale;

	/** use the same locale to translate the item name, instead of the request locale (i.e. "español" instead of "spanish") */
	private boolean selfTranslated;

	public LocaleMenuItemData() {
		// label translation will be handled here
		setTranslateLabel(false); 
		setUrlBuilder(new UrlBuilder());
	}
	public LocaleMenuItemData(Locale locale) {
		this();
		setLocale(locale);
	}
	
	public void setLocale(Locale locale) {
		this.locale = locale;
		addParameter("locale", locale.toString());
	}

	@Override
	public UrlTag getUrlTag(LoomServletRequest request, LoomServletResponse response) {
		UrlTag tag = super.getUrlTag(request, response);
		tag.setTitle(locale.getDisplayLanguage(selfTranslated? locale : request.getLocale()).toLowerCase());
		tag.setHreflang(locale.toString());
		return tag;
	}
	
	public boolean isSelfTranslated() {
		return selfTranslated;
	}

	public void setSelfTranslated(boolean selfTranslated) {
		this.selfTranslated = selfTranslated;
	}

	public Locale getLocale() {
		return locale;
	}

}
