/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.tags.messages;

import java.io.IOException;

import javax.servlet.jsp.JspException;

import org.loom.i18n.Message;
import org.loom.i18n.Messages;
import org.loom.mapping.ParsedAction;
import org.loom.tags.AbstractTag;
import org.tldgen.annotations.Attribute;
import org.tldgen.annotations.BodyContent;
import org.tldgen.annotations.Tag;


/**
 * Prints one error message. If the error message is  empty, prints nothing
 * @author icoloma
 */
@Tag(
		dynamicAttributes=true,
		bodyContent=BodyContent.EMPTY
	)
public class ErrorTag extends AbstractTag {

	/** The property name */
	@Attribute(required=true)
	private String name;
	
	/** the message to print, lazily initialized */
	private Message message;
	
	@Override
	public void doTagImpl() throws JspException, IOException {
		message = initMessage();
		if (message != null) { 
			out.print("<span class=\"error\">");
			out.print(repository.translateMessage(message));
			out.print("</span>\n");
			message.setRendered(true);
		}
	}
	
	/**
	 * @return the corresponding error message
	 */
	protected Message initMessage() {
		ParsedAction parsedAction = request.getParsedAction();
		if (parsedAction != null) {
			Messages messages = parsedAction.getMessages();
			if (messages != null) {
				return messages.get(name);
			}
		}
		return null;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

}
