/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.util;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.channels.Channels;
import java.nio.channels.FileChannel;
import java.nio.channels.WritableByteChannel;

import org.apache.commons.io.IOUtils;

public class FileUtils {

	/**
	 * Copy one stream into another, using NIO if possible.
	 * Does not close any of the two.
	 * @param input
	 * @param output
	 * @throws IOException
	 */
	public static void copy(InputStream input, OutputStream output) throws IOException {
		if (input instanceof FileInputStream) { // can we use nio?
			FileChannel in = ((FileInputStream)input).getChannel();
			WritableByteChannel out = output instanceof FileOutputStream? ((FileOutputStream)output).getChannel() : Channels.newChannel(output);
			in.transferTo(0, in.size(), out);
		} else {
			IOUtils.copy(input, output);
		}
	}

}
