/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.loom.validator;

import org.antlr.runtime.ANTLRStringStream;
import org.antlr.runtime.CommonTokenStream;
import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.TokenStream;
import org.loom.exception.ParseException;
import org.loom.validator.date.DateValue;
import org.loom.validator.date.DateValueLexer;
import org.loom.validator.date.DateValueParser;

/**
 * ANTLR does not make it easy to parse values, this class is a decorator over it.
 * To generate the ANTLR parsers, use "ant antlr"
 * @author Ignacio Coloma
 */
public class ValueParser {

	/**
	 * Parse a date value like "today + 15d"
	 */
	public static DateValue parseDateValue(String text) {
		try {
			try {
				ANTLRStringStream stream = new ANTLRStringStream(text);
				TokenStream ts = new CommonTokenStream(new DateValueLexer(stream));
				DateValueParser parser = new DateValueParser(ts);
				parser.validation();
				DateValue dateValue = parser.getDateValue();
				dateValue.setParseExpression(text);
				return dateValue;
			} catch (RecognitionException e) {
				throw new ParseException(e);
			}
		} catch (ParseException e) {
			throw new ParseException(text, e);
		}
	}
	

	
}
